@@ -13,7 +13,7 @@
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 # 
-# RCS: @(#) $Id$
+# RCS: @(#) $Id: ftp.tcl,v 1.42 2006/09/22 23:08:04 andreas_kupries Exp $
 #
 #   core ftp support: 	ftp::Open <server> <user> <passwd> <?options?>
 #			ftp::Close <s>
@@ -246,7 +246,8 @@ proc ::ftp::StateHandler {s {sock ""}} {
 
     if { $sock != "" } {
 
-        set number [gets $sock bufline]
+        set number 0                            ;# Error condition
+        catch {set number [gets $sock bufline]}
 
         if { $number > 0 } {
 
@@ -280,7 +281,9 @@ proc ::ftp::StateHandler {s {sock ""}} {
             if { $VERBOSE } {
                 DisplayMsg $s "C: 421 Service not available, closing control connection." control
             }
-            set ftp(Error) "Service not available!"
+            if {![string equal $ftp(State) "quit_sent"]} {
+		set ftp(Error) "Service not available!"
+	    }
             CloseDataConn $s
             WaitComplete $s 0
 	    Command $ftp(Command) terminated
@@ -1157,8 +1160,8 @@ proc ::ftp::NList {s { dir ""}} {
     }
 
     unset ftp(Dir)
-    if { $rc } { 
-        return [lsort $ftp(List)]
+    if { $rc } {
+	return [lsort [split [string trim $ftp(List) \n] \n]]
     } else {
         CloseDataConn $s
         return {}
@@ -2985,4 +2988,4 @@ if { [string equal [uplevel "#0" {info commands tkcon}] "tkcon"] } {
 # ==================================================================
 # At last, everything is fine, we can provide the package.
 
-package provide ftp [lindex {Revision: 2.4.1} 1]
+package provide ftp [lindex {Revision: 2.4.4} 1]
