@@ -9,7 +9,7 @@
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 #
-# RCS: @(#) $Id: list.tcl,v 1.11 2004/01/30 06:58:52 andreas_kupries Exp $
+# RCS: @(#) $Id: sets.tcl,v 1.11 2006/09/19 23:36:18 andreas_kupries Exp $
 #
 #----------------------------------------------------------------------
 
@@ -329,7 +329,7 @@ proc ::struct::set::Cleanup {A} {
 proc ::struct::set::Sinclude {Avar element} {
     # Avar = Avar + {element}
     upvar 1 $Avar A
-    if {![Scontains $A $element]} {
+    if {![info exists A] || ![Scontains $A $element]} {
 	lappend A $element
     }
     return
@@ -438,4 +438,4 @@ namespace eval ::struct {
     namespace import -force set::set
     namespace export set
 }
-package provide struct::set 2.1
+package provide struct::set 2.1.1
